@@ -10,10 +10,10 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Git; # git description: v2.043-11-g9d36216
+package Dist::Zilla::Plugin::Git; # git description: v2.049-2-g22fddc0
 # ABSTRACT: Update your git repository after release
 
-our $VERSION = '2.044';
+our $VERSION = '2.050';
 
 1;
 
@@ -29,7 +29,7 @@ Dist::Zilla::Plugin::Git - Update your git repository after release
 
 =head1 VERSION
 
-version 2.044
+version 2.050
 
 =head1 DESCRIPTION
 
@@ -110,15 +110,13 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen Jérôme Quelin Karen Etheridge Kent Fredric Yanick Champoux Ricardo Signes David Golden Mike Friedman Graham Knop Chris Weyl Stephen R. Scaffidi Randy Stauner Barr Apocalypse Doherty Nigel Metheringham Olivier Mengué Tatsuhiko Miyagawa Tuomas Jormola Alessandro Ghedini Brian Phillips Steinbrunner Geoffrey Broadwell Harley Pig Jesse Luehrs Brendan Byrd Alexandr Ciornii Matt Follett Michael Schout
+=for stopwords Christopher J. Madsen Jérôme Quelin Karen Etheridge Kent Fredric Yanick Champoux Ricardo Signes David Golden Graham Knop Mike Friedman Chris Weyl Stephen R. Scaffidi Apocalypse Curtis Jewell Barr Doherty Mikko Koivunalho Randy Stauner Alessandro Ghedini Alexandr Ciornii Brendan Byrd Brian Phillips Steinbrunner Geoffrey Broadwell Harley Pig Jesse Luehrs Matt Follett Michael McClimon Schout Nigel Metheringham Olivier Mengué Sean Whitton Tatsuhiko Miyagawa Tuomas Jormola
 
 =over 4
 
@@ -152,11 +150,11 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Mike Friedman <friedo@friedo.com>
+Graham Knop <haarg@haarg.org>
 
 =item *
 
-Graham Knop <haarg@haarg.org>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
@@ -168,7 +166,11 @@ Stephen R. Scaffidi <sscaffid@akamai.com>
 
 =item *
 
-Randy Stauner <randy@magnificent-tears.com>
+Apocalypse <perl@0ne.us>
+
+=item *
+
+Curtis Jewell <CSJEWELL@cpan.org>
 
 =item *
 
@@ -176,27 +178,15 @@ Graham Barr <gbarr@pobox.com>
 
 =item *
 
-Apocalypse <perl@0ne.us>
-
-=item *
-
 Mike Doherty <doherty@cs.dal.ca>
 
 =item *
 
-Nigel Metheringham <nigel.metheringham@dev.intechnology.co.uk>
+Mikko Koivunalho <mikkoi@cpan.org>
 
 =item *
 
-Olivier Mengué <dolmen@cpan.org>
-
-=item *
-
-Tatsuhiko Miyagawa <miyagawa@bulknews.net>
-
-=item *
-
-Tuomas Jormola <tj@solitudo.net>
+Randy Stauner <randy@magnificent-tears.com>
 
 =item *
 
@@ -204,6 +194,14 @@ Alessandro Ghedini <al3xbio@gmail.com>
 
 =item *
 
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Brendan Byrd <Perl@ResonatorSoft.org>
+
+=item *
+
 Brian Phillips <bphillips@digitalriver.com>
 
 =item *
@@ -224,20 +222,36 @@ Jesse Luehrs <doy@tozt.net>
 
 =item *
 
-Brendan Byrd <Perl@ResonatorSoft.org>
-
-=item *
-
-Alexandr Ciornii <alexchorny@gmail.com>
-
-=item *
-
 Matt Follett <matt.follett@gmail.com>
 
 =item *
 
+Michael McClimon <michael@mcclimon.org>
+
+=item *
+
 Michael Schout <mschout@gkg.net>
 
+=item *
+
+Nigel Metheringham <nigel.metheringham@dev.intechnology.co.uk>
+
+=item *
+
+Olivier Mengué <dolmen@cpan.org>
+
+=item *
+
+Sean Whitton <spwhitton@spwhitton.name>
+
+=item *
+
+Tatsuhiko Miyagawa <miyagawa@bulknews.net>
+
+=item *
+
+Tuomas Jormola <tj@solitudo.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
