@@ -13,12 +13,11 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Check;
 # ABSTRACT: Check your git repository before releasing
 
-our $VERSION = '2.044';
+our $VERSION = '2.050';
 
 use Moose;
 use namespace::autoclean 0.09;
-use Moose::Util::TypeConstraints qw(enum);
-use MooseX::Types::Moose qw(Bool);
+use Types::Standard qw(Bool Enum);;
 
 with 'Dist::Zilla::Role::AfterBuild',
     'Dist::Zilla::Role::BeforeRelease',
@@ -28,7 +27,7 @@ with 'Dist::Zilla::Role::Git::DirtyFiles',
 
 has build_warnings => ( is=>'ro', isa => Bool, default => 0 );
 
-has untracked_files => ( is=>'ro', isa => enum([qw(die warn ignore)]), default => 'die' );
+has untracked_files => ( is=>'ro', isa => Enum([qw(die warn ignore)]), default => 'die' );
 
 sub _git_config_mapping { +{
    changelog => '%{changelog}s',
@@ -61,7 +60,7 @@ sub _perform_checks {
 
     # fetch current branch
     my ($branch) =
-        map { /^\*\s+(.+)/ ? $1 : () }
+        map /^\*\s+(.+)/ ? $1 : (),
         $git->branch;
 
     # check if some changes are staged for commit
@@ -71,7 +70,7 @@ sub _perform_checks {
 
         my $errmsg =
             "branch $branch has some changes staged for commit:\n" .
-            join "\n", map { "\t$_" } @output;
+            join "\n", map "\t$_", @output;
         $self->$log_method($errmsg);
     }
 
@@ -83,7 +82,7 @@ sub _perform_checks {
 
         my $errmsg =
             "branch $branch has some uncommitted files:\n" .
-            join "\n", map { "\t$_" } @output;
+            join "\n", map "\t$_", @output;
         $self->$log_method($errmsg);
     }
 
@@ -101,7 +100,7 @@ sub _perform_checks {
 
         my $errmsg =
             "branch $branch has some untracked files:\n" .
-                join "\n", map { "\t$_" } @output;
+                join "\n", map "\t$_", @output;
         $self->$log_method($errmsg);
       }
     }
@@ -140,7 +139,7 @@ Dist::Zilla::Plugin::Git::Check - Check your git repository before releasing
 
 =head1 VERSION
 
-version 2.044
+version 2.050
 
 =head1 SYNOPSIS
 
@@ -210,8 +209,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
